#include <libxl.h>
#include <stdexcept>
#include "LoadFromExcel.h"
#include "../../excel/excel.h"
#include "../../Data/Datastructure/CarDealer/CarDealerMap.h"
#include "../../Datastructure/RepairSuggestion/RepairRecommandationRecord.h"

using namespace std;
using namespace libxl;

//车商方案表
const unsigned int CARDEALER_SCHEMA_CAPTION_COUNT = 9;
const wchar_t *    pwszSchema[]                   = {
	L"年度",
	L"月份",
	L"车商代码",
	L"车商名称",
	L"工时标准",
	L"配件价格",
	L"其他理赔支持",
	L"营销活动方案",
	L"是否达成预期",
};

//车商业绩表
const unsigned int CARDEALER_ACHIEVEMENT_CAPTION_COUNT = 10;
const wchar_t *    pwszAchievement[]                   = {
	L"年度",
	L"月份",
	L"车商代码",
	L"车商名称",
	L"店内双签产值(万元）",
	L"店内新车开票数",
	L"我司新车签单台次",
	L"人保新车签单台次",
	L"平安新车签单台次",
	L"其他保险公司新车签单台次",
};

//送返修工单
const unsigned int REPAIR_ORDER_CAPTION_COUNT = 25;
const wchar_t *    pwszRepairOrderCaption[]   = {
	L"分公司名称",
	L"工单号",
	L"工单类型",
	L"报案号",
	L"出险区域",
	L"出险日期",
	L"创建日期",
	L"商业险保单号",
	L"交强险保单号",
	L"车牌号",
	L"品牌名称",
	L"是否标的车",
	L"是否推荐成功",
	L"推荐车商代码",
	L"推荐车商名称",
	L"报案推荐车商名称",
	L"查勘推荐车商名称",
	L"接报案人",
	L"查勘员",
	L"工单确认时间",
	L"车辆进厂时间",
	L"车辆出厂时间",
	L"状态",
	L"损失项目ID",
	L"查勘员推荐状态",
};

//卢霖城-送返修推荐表
const unsigned int REPAIR_RECOMMANDATION_CAPTION_COUNT = 11;
const wchar_t *    pwszRepairRecommandationCaption[]   = {
	L"分公司名称",
	L"工单号",
	L"工单类型",
	L"报案号",
	L"推荐车商代码",
	L"推荐车商名称",
	L"出险日期",
	L"车牌号",
	L"品牌名称",
	L"短信类型",
	L"发送时间",
	L"数据来源",
};

//新送返修推荐报表
const unsigned int NEW_REPAIR_MONITOR_CAPTION_COUNT = 157;
const wchar_t *    pwszNewRepairMonitorCaption[]    = {
	L"分公司名称",
	L"部门组名称",
	L"报案号",
	L"报案日期",
	L"出险日期",
	L"出险地点",
	L"事故车目前位置",
	L"车损序号",
	L"车牌",
	L"vin码",
	L"车龄",
	L"品牌代码",
	L"品牌名称",
	L"车系名称",
	L"使用性质名称",
	L"保单号",
	L"标的车/三者车",
	L"是否9座以下企业用车、行政用车、家庭自用车",
	L"核价金额",
	L"核损配件核损金额",
	L"核损工时费核损金额",
	L"核损辅料核损金额",
	L"核损外修费核损金额",
	L"核损施救费核损金额",
	L"结案金额",
	L"结案配件核损金额",
	L"结案工时费核损金额",
	L"结案辅料核损金额",
	L"结案外修费核损金额",
	L"结案施救费核损金额",
	L"接报案人分公司名称",
	L"接报案人工号",
	L"接报案人名称",
	L"第一任务分派时间",
	L"第一定损员分公司",
	L"第一定损员部门组名称",
	L"第一定损员代码",
	L"第一定损员名称",
	L"第一车商是否已阅读",
	L"第一车上是否预约进厂",
	L"第一车商是否推荐失败",
	L"第一车商是否进厂确认",
	L"第一车商是否出场确认",
	L"第二任务分派时间",
	L"第二定损员分公司",
	L"第二定损员部门组名称",
	L"第二定损员代码",
	L"第二定损员名称",
	L"第二车商是否已阅读",
	L"第二车上是否预约进厂",
	L"第二车商是否推荐失败",
	L"第二车商是否进厂确认",
	L"第二车商是否出场确认",
	L"第三任务分派时间",
	L"第三定损员分公司",
	L"第三定损员部门组名称",
	L"第三定损员代码",
	L"第三定损员名称",
	L"第三车商是否已阅读",
	L"第三车上是否预约进厂",
	L"第三车商是否推荐失败",
	L"第三车商是否进厂确认",
	L"第三车商是否出场确认",
	L"其他查勘员信息",
	L"是否推荐",
	L"是否存在工单",
	L"工单类型",
	L"查勘员操作类型",
	L"案件状态名称",
	L"车辆状态名称--当前状态",
	L"车辆状态名称--报案环节",
	L"车辆状态名称--现场推荐环节",
	L"车辆状态名称--核价通过环节",
	L"车辆状态名称--结案环节",
	L"承保车商代码",
	L"承保车商名称",
	L"报案车商分公司名称",
	L"报案车商部门组名称",
	L"报案车商代码",
	L"报案车商名称",
	L"现场推荐车商分公司名称",
	L"现场推荐车商代码",
	L"现场推荐车商名称",
	L"核价车商分公司名称",
	L"核价车商部门组名称",
	L"核价车商代码",
	L"核价车商名称",
	L"推荐车商与核价车商是否一致",
	L"核价修理厂归属公司代码",
	L"核价修理厂归属公司名称",
	L"核价修理厂",
	L"核价修理厂名称",
	L"估损单号",
	L"核价通过时间",
	L"定损员机构",
	L"定损员代码",
	L"定损员名称",
	L"结案车商分公司",
	L"结案车商部门组名称",
	L"结案车商代码",
	L"结案车商名称",
	L"推荐车商与结案车商是否一致",
	L"结案修理厂归属公司代码",
	L"结案修理厂归属公司名称",
	L"结案修理厂代码",
	L"结案修理厂名称",
	L"车辆进厂时间",
	L"车辆出厂时间",
	L"结案时间",
	L"事故经过",
	L"数据更新日期",
	L"备注",
	L"估损单模板",
	L"返修开关(报案)",
	L"送修开关(报案)",
	L"返修开关(核价)",
	L"送修开关(核价)",
	L"返修开关(结案)",
	L"送修开关(结案)",
	L"查勘员分公司名称",
	L"查勘员代码",
	L"查勘员名称",
	L"核价修理厂归属中支",
	L"结案修理厂归属中支",
	L"是否诉讼",
	L"座席推荐分公司代码",
	L"座席推荐分公司名称",
	L"座席推荐车商名代码",
	L"座席推荐车商名称",
	L"座席推荐操作类型",
	L"座席推荐排名",
	L"第一次推荐分公司代码 ",
	L"第一次推荐分公司名称",
	L"第一次推荐车商代码",
	L"第一次推荐车商名称",
	L"第一次推荐工具（APP、M6）",
	L"第一次推荐操作类型",
	L"第一次推荐排名、其他推荐信息",
	L"第二次推荐分公司代码",
	L"第二次推荐分公司名称",
	L"第二次推荐车商代码",
	L"第二次推荐车商名称",
	L"第二次推荐工具（APP、M6）",
	L"第二次推荐操作类型",
	L"第二次推荐排名、其他推荐信息",
	L"第三次推荐分公司代码 ",
	L"第三次推荐分公司名称",
	L"第三次推荐车商代码",
	L"第三次推荐车商名称",
	L"第三次推荐工具（APP、M6）",
	L"第三次推荐操作类型",
	L"第三次推荐排名、其他推荐信息",
	L"其他推荐信息",
	L"推荐失败具体原因",
	L"是否现场报案",
	L"报案地点",
	L"是否在厂报案",
};

/************************************************
* \brief 
* \param pBook 
* \param sheetIndex 
* \param captionRowIndex 
* \param pszCaptionFormat 
* \param captionCount 
* \return 
************************************************/
bool checkExcelFileFormat( Book *          pBook,
                           int             sheetIndex,
                           int             captionRowIndex,
                           const wchar_t * pszCaptionFormat[],
                           int             captionCount );

/************************************************
* \brief 从Excel文件读取车商方案表
* \param filePath Excel文件路径
* \param schemeMap 存放车商方案数据的map
************************************************/
void LoadCarDealerSchemeFromXlsx( const wstring &           filePath,
                                  unsigned int              sheetIndex,
                                  unsigned int              startRowIndex,
                                  vector<CarDealerScheme> & schemeVector )
{
	Book *  pBook  = xlCreateXMLBookW();
	Sheet * pSheet = nullptr;

	if ( pBook == nullptr )
	{
		throw runtime_error( "libxl库加载失败！" );
	}

	setKey( pBook );

	if ( pBook->load( filePath.c_str() ) != true )
	{
		string errorMessage = "打开文件失败！";
		errorMessage.append( pBook->errorMessage() );

		throw runtime_error( errorMessage );
	}

	//验证表格内容是否相符
	bool isEqual = checkExcelFileFormat( pBook,
	                                     sheetIndex,
	                                     startRowIndex - 1,
	                                     pwszSchema,
	                                     CARDEALER_SCHEMA_CAPTION_COUNT );

	if ( isEqual == false )
	{
		//内容不相符，抛出异常
		string errorMessage = "Excel文件内容不符！\n请核对后再导入！";

		pBook->release();

		throw runtime_error( errorMessage );
	}

	pSheet = pBook->getSheet( sheetIndex );

	if ( pSheet == nullptr )
	{
		string errorMessage = "读取sheet失败！";
		errorMessage.append( pBook->errorMessage() );

		pBook->release();

		throw runtime_error( errorMessage );
	}

	int lastRowIndex     = pSheet->lastRow();
	int firstRowIndex    = pSheet->firstRow();
	int firstColumnIndex = pSheet->firstCol();
	int rowIndex         = firstRowIndex + startRowIndex;

	//车商名称表，用于验证表格中的车商代码
	auto * pCarDealerMap = GetCarDealerMap();

	while ( rowIndex <= lastRowIndex )
	{
		int colunmIndex = firstRowIndex;

		const wstring && theYear       = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex, true );
		const wstring && theMonth      = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex + 1, true );
		const wstring && carDealerCode = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex + 2, true );
		//const wstring && carDealerName = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex + 3, true );
		const wstring && manHourPrice = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex + 4, true );
		const wstring && partPrice    = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex + 5, true );
		const wstring && claimSupport = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex + 6, true );
		const wstring && scheme       = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex + 7, true );
		const wstring && isQualified  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex + 8, true );

		//空行跳过
		if ( carDealerCode.empty() == true )
		{
			rowIndex++;

			continue;
		}

		//核对车商代码
		auto iterCarDealer = pCarDealerMap->find( carDealerCode );

		if ( iterCarDealer == pCarDealerMap->end() )
		{
			//没查到这个车商，清除掉已经读取的数据
			schemeVector.clear();
			QString rowIndexString = QString::number( rowIndex, 'g', -1 );
			QString errorMessage   = QString( "第" ) + rowIndexString + QString( "行车商代码错误！" );

			throw runtime_error( errorMessage.toStdString() );
		}

		CarDealerScheme carDealerScheme( theYear,
		                                 theMonth,
		                                 carDealerCode,
		                                 manHourPrice,
		                                 partPrice,
		                                 claimSupport,
		                                 scheme,
		                                 isQualified );

		schemeVector.push_back( carDealerScheme );

		rowIndex++;
	}

	pBook->release();
}

void LoadCarDealerAchievementFromXlsx( const std::wstring &                filePath,
                                       unsigned                            sheetIndex,
                                       unsigned                            startRowIndex,
                                       std::vector<CarDealerAchievement> & achievementVector )
{
	Book *  pBook  = xlCreateXMLBookW();
	Sheet * pSheet = nullptr;

	if ( pBook == nullptr )
	{
		throw runtime_error( "libxl库加载失败！" );
	}

	setKey( pBook );

	if ( pBook->load( filePath.c_str() ) != true )
	{
		string errorMessage = "打开文件失败！";
		errorMessage.append( pBook->errorMessage() );

		throw runtime_error( errorMessage );
	}

	//验证表格内容是否相符
	bool isEqual = checkExcelFileFormat( pBook, sheetIndex, startRowIndex - 1, pwszAchievement, CARDEALER_ACHIEVEMENT_CAPTION_COUNT );

	if ( isEqual == false )
	{
		//内容不相符，抛出异常
		string errorMessage = "Excel文件内容不符！\n请核对后再导入！";

		pBook->release();

		throw runtime_error( errorMessage );
	}

	pSheet = pBook->getSheet( sheetIndex );

	if ( pSheet == nullptr )
	{
		string errorMessage = "读取sheet失败！";
		errorMessage.append( pBook->errorMessage() );

		pBook->release();

		throw runtime_error( errorMessage );
	}

	int lastRowIndex     = pSheet->lastRow();
	int firstRowIndex    = pSheet->firstRow();
	int firstColumnIndex = pSheet->firstCol();
	int rowIndex         = firstRowIndex + startRowIndex;

	//车商名称表
	unordered_map<wstring, CarDealer> * pCarDealerMap = GetCarDealerMap();

	while ( rowIndex <= lastRowIndex )
	{
		int colunmIndex = firstRowIndex;

		const wstring && theYear       = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex, true );
		const wstring && theMonth      = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex + 1, true );
		const wstring && carDealerCode = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex + 2, true );
		//const wstring && carDealerName      = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex + 3, true );
		long double checkedAchievement = 0;
		int         policyAmount       = 0;
		int         cpicAmount         = 0;
		int         piccAmount         = 0;
		int         pinganAmount       = 0;
		int         othersAmount       = 0;

		//空行跳过
		if ( carDealerCode.empty() == true )
		{
			rowIndex++;

			continue;
		}

		//核对车商代码
		auto iterCarDealer = pCarDealerMap->find( carDealerCode );

		if ( iterCarDealer == pCarDealerMap->end() )
		{
			//没查到这个车商，清除掉已经读取的数据
			achievementVector.clear();
			QString rowIndexString = QString::number( rowIndex, 'g', -1 );
			QString errorMessage   = QString( "第" ) + rowIndexString + QString( "行车商代码错误！" );

			pBook->release();

			throw runtime_error( errorMessage.toStdString() );
		}

		//每个字段都要先判断数据类型再读写，防止填写表格的人填错内容。
		CellType type = pSheet->cellType( rowIndex, firstColumnIndex + 4 );
		char     errorMessage[1000];

		//产值
		if ( type == CELLTYPE_NUMBER )
		{
			checkedAchievement = pSheet->readNum( rowIndex, firstColumnIndex + 4 );
		}
		else
		{
			pBook->release();

			sprintf( errorMessage, "第%d行第%d列，格式错误，不是数字类型！", rowIndex, firstColumnIndex + 4 );

			throw runtime_error( errorMessage );
		}

		//签单数量
		type = pSheet->cellType( rowIndex, firstColumnIndex + 5 );

		if ( type == CELLTYPE_NUMBER )
		{
			policyAmount = static_cast<int>(pSheet->readNum( rowIndex, firstColumnIndex + 5 ));
		}
		else
		{
			pBook->release();

			sprintf( errorMessage, "第%d行第%d列，格式错误，不是数字类型！", rowIndex, firstColumnIndex + 5 );

			throw runtime_error( errorMessage );
		}

		//太平洋保险新车签单台次
		type = pSheet->cellType( rowIndex, firstColumnIndex + 6 );

		if ( type == CELLTYPE_NUMBER )
		{
			cpicAmount = static_cast<int>(pSheet->readNum( rowIndex, firstColumnIndex + 6 ));
		}
		else
		{
			pBook->release();

			sprintf( errorMessage, "第%d行第%d列，格式错误，不是数字类型！", rowIndex, firstColumnIndex + 6 );

			throw runtime_error( errorMessage );
		}

		//中国人保新车签单台次
		type = pSheet->cellType( rowIndex, firstColumnIndex + 7 );

		if ( type == CELLTYPE_NUMBER )
		{
			piccAmount = static_cast<int>(pSheet->readNum( rowIndex, firstColumnIndex + 7 ));
		}
		else
		{
			pBook->release();

			sprintf( errorMessage, "第%d行第%d列，格式错误，不是数字类型！", rowIndex, firstColumnIndex + 7 );

			throw runtime_error( errorMessage );
		}

		//中国平安新车签单台次
		type = pSheet->cellType( rowIndex, firstColumnIndex + 8 );

		if ( type == CELLTYPE_NUMBER )
		{
			pinganAmount = static_cast<int>(pSheet->readNum( rowIndex, firstColumnIndex + 8 ));
		}
		else
		{
			pBook->release();

			sprintf( errorMessage, "第%d行第%d列，格式错误，不是数字类型！", rowIndex, firstColumnIndex + 8 );

			throw runtime_error( errorMessage );
		}

		//其他保险公司新车签单台次
		type = pSheet->cellType( rowIndex, firstColumnIndex + 9 );

		if ( type == CELLTYPE_NUMBER )
		{
			othersAmount = static_cast<int>(pSheet->readNum( rowIndex, firstColumnIndex + 9 ));
		}
		else
		{
			pBook->release();

			sprintf( errorMessage, "第%d行第%d列，格式错误，不是数字类型！", rowIndex, firstColumnIndex + 9 );

			throw runtime_error( errorMessage );
		}

		CarDealerAchievement achievement( theYear,
		                                  theMonth,
		                                  carDealerCode,
		                                  checkedAchievement,
		                                  policyAmount,
		                                  cpicAmount,
		                                  piccAmount,
		                                  pinganAmount,
		                                  othersAmount );

		achievementVector.push_back( achievement );

		rowIndex++;
	}

	pBook->release();
}

void LoadRepairOrderFromXlsx( const std::wstring &       filePath,
                              unsigned                   sheetIndex,
                              unsigned                   startRowIndex,
                              std::vector<RepairOrder> & orderVector )
{
	Book *  pBook  = xlCreateXMLBookW();
	Sheet * pSheet = nullptr;

	if ( pBook == nullptr )
	{
		throw runtime_error( "libxl库加载失败！" );
	}

	setKey( pBook );

	if ( pBook->load( filePath.c_str() ) != true )
	{
		string errorMessage = "打开文件失败！";
		errorMessage.append( pBook->errorMessage() );

		throw runtime_error( errorMessage );
	}

	//验证表格内容是否相符
	bool isEqual = checkExcelFileFormat( pBook,
	                                     sheetIndex,
	                                     startRowIndex - 1,
	                                     pwszRepairOrderCaption,
	                                     REPAIR_ORDER_CAPTION_COUNT );

	if ( isEqual == false )
	{
		//内容不相符，抛出异常
		string errorMessage = "Excel文件内容不符！\n请核对后再导入！";

		pBook->release();

		throw runtime_error( errorMessage );
	}

	pSheet = pBook->getSheet( sheetIndex );

	if ( pSheet == nullptr )
	{
		string errorMessage = "读取sheet失败！";
		errorMessage.append( pBook->errorMessage() );

		pBook->release();

		throw runtime_error( errorMessage );
	}

	int lastRowIndex  = pSheet->lastRow();
	int firstRowIndex = pSheet->firstRow();
	int rowIndex      = firstRowIndex + startRowIndex;

	auto * pCarDealerMap = GetCarDealerMap();

	while ( rowIndex <= lastRowIndex )
	{
		int colunmIndex = pSheet->firstCol();

		//报案推荐车商代码在表格中不存在，但在数据库中存在。
		const wstring && branchName                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && orderNo                     = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && orderType                   = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && notifyNo                    = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && damageArea                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && damageDate                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && generatingDate              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && policyNo                    = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && policyNoJQX                 = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && plateNumber                 = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && brandName                   = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && isInsuranceObject           = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && isSuccess                   = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && recommandDealerCode         = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && recommandDealerName         = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && recommandDealerCodeInNotify = L""; //表格中没有报案推荐车商代码
		const wstring && recommandDealerNameInNotify = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && recommandDealerNameInSurvey = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && agentName                   = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && surveyor                    = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && checkDate                   = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && repairingStartDate          = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && repairingFinishDate         = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && status                      = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && lostItemID                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		const wstring && surveyorRecommandStatus     = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );

		//空行跳过
		if ( orderNo.empty() == true )
		{
			rowIndex++;

			continue;
		}

		RepairOrder order( branchName,
		                   orderNo,
		                   orderType,
		                   notifyNo,
		                   damageArea,
		                   damageDate,
		                   generatingDate,
		                   policyNo,
		                   policyNoJQX,
		                   plateNumber,
		                   brandName,
		                   isInsuranceObject,
		                   isSuccess,
		                   recommandDealerCode,
		                   recommandDealerName,
		                   recommandDealerCodeInNotify,
		                   recommandDealerNameInNotify,
		                   recommandDealerNameInSurvey,
		                   agentName,
		                   surveyor,
		                   checkDate,
		                   repairingStartDate,
		                   repairingFinishDate,
		                   status,
		                   lostItemID,
		                   surveyorRecommandStatus );

		orderVector.push_back( order );

		rowIndex++;
	}

	pBook->release();
}

void LoadRepairRecommandationFromXlsx( const std::wstring &                      filePath,
                                       unsigned                                  sheetIndex,
                                       unsigned                                  startRowIndex,
                                       std::vector<RepairRecommandationRecord> & recordVector )
{
	Book *  pBook  = xlCreateXMLBookW();
	Sheet * pSheet = nullptr;

	if ( pBook == nullptr )
	{
		throw runtime_error( "libxl库加载失败！" );
	}

	if ( pBook->load( filePath.c_str() ) != true )
	{
		string errorMessage = "打开文件失败！";
		errorMessage.append( pBook->errorMessage() );

		throw runtime_error( errorMessage );
	}

	setKey( pBook );

	//验证表格内容是否相符
	bool isEqual = checkExcelFileFormat( pBook,
	                                     sheetIndex,
	                                     startRowIndex - 1,
	                                     pwszRepairRecommandationCaption,
	                                     REPAIR_RECOMMANDATION_CAPTION_COUNT );

	if ( isEqual == false )
	{
		//内容不相符，抛出异常
		string errorMessage = "Excel文件内容不符！\n请核对后再导入！";

		pBook->release();

		throw runtime_error( errorMessage );
	}

	pSheet = pBook->getSheet( sheetIndex );

	if ( pSheet == nullptr )
	{
		string errorMessage = "读取sheet失败！";
		errorMessage.append( pBook->errorMessage() );

		pBook->release();

		throw runtime_error( errorMessage );
	}

	int lastRowIndex  = pSheet->lastRow();
	int firstRowIndex = pSheet->firstRow();
	int rowIndex      = firstRowIndex + startRowIndex;

	while ( rowIndex <= lastRowIndex )
	{
		//起始列索引
		int colunmIndex = pSheet->firstCol();

		wstring branchName             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		wstring orderNo                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		wstring orderType              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		wstring notifyNo               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		wstring RecommandCarDealerCode = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		wstring RecommandCarDealerName = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		wstring damageDate             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		wstring plateNumber            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		wstring brandName              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		wstring messageType            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		wstring messageSendingDate     = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		wstring dataSource             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );

		RepairRecommandationRecord record( branchName,
			                               orderNo,
		                                   orderType,
		                                   notifyNo,
		                                   RecommandCarDealerCode,
		                                   RecommandCarDealerName,
		                                   damageDate,
		                                   plateNumber,
		                                   brandName,
		                                   messageType,
		                                   messageSendingDate,
		                                   dataSource );

		recordVector.push_back( record );

		rowIndex++;
	}

	pBook->release();
}

void LoadNewRepairMonitorReportFromXlsx( const std::wstring &                        filePath,
                                         unsigned                                    sheetIndex,
                                         unsigned                                    startRowIndex,
                                         std::vector<NewRepairMonitorReportRecord> & recordVector )
{
	Book *  pBook  = xlCreateXMLBookW();
	Sheet * pSheet = nullptr;

	if ( pBook == nullptr )
	{
		throw runtime_error( "libxl库加载失败！" );
	}

	setKey( pBook );

	if ( pBook->load( filePath.c_str() ) != true )
	{
		string errorMessage = "打开文件失败！";
		errorMessage.append( pBook->errorMessage() );

		throw runtime_error( errorMessage );
	}

	//验证表格内容是否相符
	bool isEqual = checkExcelFileFormat( pBook,
	                                     sheetIndex,
	                                     startRowIndex - 1,
	                                     pwszNewRepairMonitorCaption,
	                                     NEW_REPAIR_MONITOR_CAPTION_COUNT );

	if ( isEqual == false )
	{
		//内容不相符，抛出异常
		string errorMessage = "Excel文件内容不符！\n请核对后再导入！";

		pBook->release();

		throw runtime_error( errorMessage );
	}

	pSheet = pBook->getSheet( sheetIndex );

	if ( pSheet == nullptr )
	{
		string errorMessage = "读取sheet失败！";
		errorMessage.append( pBook->errorMessage() );

		pBook->release();

		throw runtime_error( errorMessage );
	}

	int lastRowIndex  = pSheet->lastRow();
	int firstRowIndex = pSheet->firstRow();
	int rowIndex      = firstRowIndex + startRowIndex;

	while ( rowIndex <= lastRowIndex )
	{
		int colunmIndex = pSheet->firstCol();

		NewRepairMonitorReportRecord record;

		record.分公司名称_ = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.部门组名称_ = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.报案号_   = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );

		if ( record.报案号_.empty() == true )
		{
			//空行跳过
			rowIndex++;

			continue;
		}

		record.报案日期_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.出险日期_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.出险地点_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.事故车目前位置_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.车损序号_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.车牌_                    = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.vin码_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.车龄_                    = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.品牌代码_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.品牌名称_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.车系名称_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.使用性质名称_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.保单号_                   = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.标的车_三者车_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.是否9座以下企业用车_行政用车_家庭自用车_ = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核价金额_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核损配件核损金额_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核损工时费核损金额_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核损辅料核损金额_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核损外修费核损金额_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核损施救费核损金额_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案金额_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案配件核损金额_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案工时费核损金额_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案辅料核损金额_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案外修费核损金额_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案施救费核损金额_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.接报案人分公司名称_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.接报案人工号_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.接报案人名称_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一任务分派时间_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一定损员分公司_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一定损员部门组名称_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一定损员代码_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一定损员名称_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一车商是否已阅读_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一车上是否预约进厂_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一车商是否推荐失败_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一车商是否进厂确认_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一车商是否出场确认_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二任务分派时间_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二定损员分公司_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二定损员部门组名称_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二定损员代码_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二定损员名称_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二车商是否已阅读_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二车上是否预约进厂_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二车商是否推荐失败_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二车商是否进厂确认_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二车商是否出场确认_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三任务分派时间_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三定损员分公司_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三定损员部门组名称_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三定损员代码_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三定损员名称_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三车商是否已阅读_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三车上是否预约进厂_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三车商是否推荐失败_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三车商是否进厂确认_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三车商是否出场确认_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.其他查勘员信息_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.是否推荐_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.是否存在工单_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.工单类型_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.查勘员操作类型_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.案件状态名称_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.车状_当前状态_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.车状_报案环节_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.车状_现场推荐环节_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.车状_核价通过环节_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.车状_结案环节_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.承保车商代码_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.承保车商名称_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.报案车商分公司名称_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.报案车商部门组名称_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.报案车商代码_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.报案车商名称_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.现场推荐车商分公司名称_           = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.现场推荐车商代码_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.现场推荐车商名称_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核价车商分公司名称_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核价车商部门组名称_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核价车商代码_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核价车商名称_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.推荐车商与核价车商是否一致_         = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核价修理厂归属公司代码_           = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核价修理厂归属公司名称_           = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核价修理厂_                 = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核价修理厂名称_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.估损单号_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核价通过时间_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.定损员机构_                 = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.定损员代码_                 = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.定损员名称_                 = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案车商分公司_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案车商部门组名称_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案车商代码_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案车商名称_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.推荐车商与结案车商是否一致_         = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案修理厂归属公司代码_           = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案修理厂归属公司名称_           = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案修理厂代码_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案修理厂名称_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.车辆进厂时间_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.车辆出厂时间_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案时间_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.事故经过_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.数据更新日期_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.备注_                    = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.估损单模板_                 = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.返修开关_报案_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.送修开关_报案_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.返修开关_核价_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.送修开关_核价_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.返修开关_结案_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.送修开关_结案_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.查勘员分公司名称_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.查勘员代码_                 = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.查勘员名称_                 = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.核价修理厂归属中支_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.结案修理厂归属中支_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.是否诉讼_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.座席推荐分公司代码_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.座席推荐分公司名称_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.座席推荐车商名代码_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.座席推荐车商名称_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.座席推荐操作类型_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.座席推荐排名_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一次推荐分公司代码_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一次推荐分公司名称_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一次推荐车商代码_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一次推荐车商名称_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一次推荐工具_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一次推荐操作类型_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第一次推荐排名_其他推荐信息_        = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二次推荐分公司代码_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二次推荐分公司名称_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二次推荐车商代码_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二次推荐车商名称_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二次推荐工具_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二次推荐操作类型_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第二次推荐排名_其他推荐信息_        = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三次推荐分公司代码_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三次推荐分公司名称_            = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三次推荐车商代码_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三次推荐车商名称_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三次推荐工具_               = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三次推荐操作类型_             = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.第三次推荐排名_其他推荐信息_        = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.其他推荐信息_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.推荐失败具体原因_              = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.是否现场报案_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.报案地点_                  = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );
		record.是否在厂报案_                = ReadCellStringFromXlsx( pBook, sheetIndex, rowIndex, colunmIndex++, true );

		recordVector.push_back( record );

		rowIndex++;
	}

	pBook->release();
}


/************************************************
* \brief 
* \param pBook 
* \param sheetIndex 
* \param captionRowIndex 
* \param pszCaptionFormat 
* \return 
************************************************/
bool checkExcelFileFormat( Book * pBook, int sheetIndex, int captionRowIndex, const wchar_t * pszCaptionFormat[], int captionCount )
{
	if ( pBook == nullptr )
	{
		throw logic_error( "Excel文件指针为空！" );
	}

	if ( sheetIndex < 0 || captionRowIndex < 0 )
	{
		throw logic_error( "标题行参数错误！" );
	}

	Sheet * pSheet       = pBook->getSheet( sheetIndex );
	int     captionIndex = 0;
	bool    isEqual      = true;

	while ( captionIndex < captionCount )
	{
		const wchar_t * pwszCaption = pSheet->readStr( captionRowIndex, captionIndex );

		if ( wcscmp( pwszCaption, pszCaptionFormat[captionIndex] ) != 0 )
		{
			isEqual = false;

			break;
		}

		captionIndex++;
	}

	return isEqual;
}
