﻿// **********************************************************
// 文件名：CarDealerMap.cpp
// 创建日期：2020-11-23 13:59
// 作者: 王炜
// 说明：车商对象映射表
// **********************************************************

#include <QString>
#include <ocilib.hpp>
#include <stdexcept>
#include "CarDealer.h"
#include "CarDealerMap.h"

#include <xlocale>

#include "../../../db/ocilib/db_oper.h"

using namespace std;
using namespace ocilib;

unordered_map<wstring, CarDealer> * pCarDealerMap = nullptr;

void InitCarDealerMap()
{
	if ( pCarDealerMap != nullptr )
	{
		delete pCarDealerMap;
	}

	OCI_Connection * pConnection = nullptr;
	OCI_Statement *  pStatement  = nullptr;
	OCI_Resultset *  pResult     = nullptr;
	int              returnCode  = 0;

	ostring sql =
			"SELECT auto_code, "
			"       auto_name "
			"FROM idst0.auto_store_t ";

	//以后要修改
	string userName = "car_dealer";
	string password = "cpic123456";
	string tnsName  = "xmcx1";

	returnCode = OCI_Initialize( error_handler, nullptr, OCI_ENV_DEFAULT );

	if ( static_cast<bool>(returnCode) == false )
	{
		//初始化失败
		string errorMessage = "ocilib初始化失败！";
	}

	//连接
	try
	{
		pConnection = OCI_ConnectionCreate( tnsName.c_str(),
		                                    userName.c_str(),
		                                    password.c_str(),
		                                    OCI_SESSION_DEFAULT );
	}
	catch ( runtime_error & error )
	{
		//连接数据库失败
		string errorMessage = "连接数据库失败！";

		errorMessage.append( error.what() );

		OCI_Cleanup();

		throw runtime_error( errorMessage.c_str() );
	}

	//查询
	try
	{
		pStatement = OCI_StatementCreate( pConnection );

		OCI_ExecuteStmt( pStatement, sql.c_str() );

		pResult       = OCI_GetResultset( pStatement );
		pCarDealerMap = new unordered_map<wstring, CarDealer>;

		while ( static_cast<bool>(OCI_FetchNext( pResult )) == true )
		{
			wstring carDealerCodeIndex = QString::fromLocal8Bit( OCI_GetString( pResult, 1 ) ).toStdWString();
			QString carDealerCode      = QString::fromLocal8Bit( OCI_GetString( pResult, 1 ) );
			QString carDealerName      = QString::fromLocal8Bit( OCI_GetString( pResult, 2 ) );

			CarDealer dealer( carDealerCode, carDealerName );

			pCarDealerMap->insert( pair<wstring, CarDealer>( carDealerCodeIndex, dealer ) );
		}
	}
	catch ( runtime_error & error )
	{
		string errorMessage = "执行查询失败！";

		errorMessage.append( error.what() );

		OCI_Cleanup();

		throw runtime_error( errorMessage.c_str() );
	}

	OCI_Cleanup();
}

void initCarDealerMapCpp()
{
	if ( pCarDealerMap != nullptr )
	{
		delete pCarDealerMap;
	}

	// OCI_Connection * pConnection = nullptr;
	// OCI_Statement *  pStatement  = nullptr;
	// OCI_Resultset *  pResult     = nullptr;
	// int returnCode = 0;

	ostring sql =
			"SELECT auto_code, "
			"       auto_name "
			"FROM idst0.auto_store_t ";

	//以后要修改
	string userName = "car_dealer";
	string password = "cpic123456";
	string tnsName  = "xmcx1";

	Connection * pConnection = nullptr;
	Statement *  pStatement  = nullptr;
	//Resultset *  pResult     = nullptr;

	try
	{
		Environment::Initialized();
	}
	catch ( exception * error )
	{
		string errorMessage = "ocilib初始化失败！";

		errorMessage.append( error->what() );

		throw runtime_error( errorMessage.c_str() );
	}

	try
	{
		pConnection = new Connection( tnsName.c_str(), userName.c_str(), password.c_str() );
	}
	catch ( exception & error )
	{
		string errorMessage = "连接oracle数据库失败！";

		errorMessage.append( error.what() );

		Environment::Cleanup();

		throw runtime_error( errorMessage.c_str() );
	}

	try
	{
		pStatement = new Statement( *pConnection );
		pStatement->Execute( sql );

		Resultset result = pStatement->GetResultset();

		pCarDealerMap = new unordered_map<wstring, CarDealer>;

		while ( result.Next() )
		{
			QString carDealerCode      = QString::fromLocal8Bit( result.Get<ostring>( "auto_code" ).c_str() );
			QString carDealerName      = QString::fromLocal8Bit( result.Get<ostring>( "auto_name" ).c_str() );
			wstring carDealerCodeIndex = carDealerCode.toStdWString();
			
			CarDealer dealer( carDealerCode, carDealerName );

			pCarDealerMap->insert( pair<wstring, CarDealer>( carDealerCodeIndex, dealer ) );
		}
	}
	catch ( exception & error )
	{
		Environment::Cleanup();
	}

	Environment::Cleanup();
}

std::unordered_map<wstring, CarDealer> * GetCarDealerMap()
{
	if ( pCarDealerMap != nullptr )
	{
		InitCarDealerMap();
	}

	return pCarDealerMap;
}

std::wstring GetCarDealerName( const std::wstring & carDealerCode )
{
	auto    pCarDealerMap = GetCarDealerMap();
	auto    iterCarDealer = pCarDealerMap->find(carDealerCode);
	wstring carDealerName;
	
	if ( iterCarDealer != pCarDealerMap->end() )
	{
		carDealerName = iterCarDealer->second.getCarDealerName().toStdWString();
	}

	return carDealerName;
}
