#include "QCarDealerSchemaWidget.h"

#include "../../../Data/DataManipulation/Excel/LoadFromExcel.h"
#include "../../../Data/DataManipulation/oracle/ImportToOracle.h"
#include "../../util/qt/qt_util.h"
#include "../../Data/Datastructure/CarDealer/CarDealerMap.h"

using namespace std;

QCarDealerSchemaWidget::QCarDealerSchemaWidget( QWidget * parent )
	: QWidget( parent )
{
	ui.setupUi( this );

	init();
}

QCarDealerSchemaWidget::~QCarDealerSchemaWidget()
{
}

void QCarDealerSchemaWidget::onImport()
{
	//选择文件
	QString xlsxFilePath = QFileDialog::getOpenFileName( this,
	                                                     "请选择要导入的数据文件",
	                                                     ".", "xlsx文件(*.xlsx)" );

	if ( xlsxFilePath.isEmpty() == true )
	{
		return;
	}

	schemeVector.clear();

	LoadCarDealerSchemeFromXlsx( xlsxFilePath.toStdWString(),
	                             0,
	                             1,
	                             schemeVector );

	//以后要修改
	string userName = "car_dealer";
	string password = "cpic123456";
	string tnsName  = "xmcx1";

	try
	{
		ImportCarDealerSchemeToOracle( userName, password, tnsName, schemeVector );

		showCarDealerSchema();
	}
	catch ( runtime_error & error )
	{
		QMessageBox::critical( this,
		                       "错误",
		                       error.what() );

		return;
	}
}

void QCarDealerSchemaWidget::init()
{
	initData();
	initWidgets();
	initSignal();
}

void QCarDealerSchemaWidget::initData()
{
}

void QCarDealerSchemaWidget::initWidgets()
{
	setLayout( ui.pLayoutMain );

	resizeTableWidgetTab( ui.pTableWidgetSchema, 10 );
}

void QCarDealerSchemaWidget::initSignal()
{
	connect( ui.pButtonImport, SIGNAL( clicked() ), this, SLOT( onImport() ) );
}

void QCarDealerSchemaWidget::showCarDealerSchema()
{
	ui.pTableWidgetSchema->clearContents();
	ui.pTableWidgetSchema->setRowCount( schemeVector.size() );
	ui.pTableWidgetSchema->horizontalHeader()->setHighlightSections(false);

	int                rowIndex    = 0;
	int                columnIndex = 0;
	QTableWidgetItem * pItem       = nullptr;

	auto carDealerMap = GetCarDealerMap();

	for ( auto iterSchema = schemeVector.begin();
	      iterSchema != schemeVector.end();
	      ++iterSchema )
	{	
		//年度
		pItem = new QTableWidgetItem( QString::fromStdWString( iterSchema->getTheYear() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetSchema->setItem( rowIndex, columnIndex++, pItem );

		//月份
		pItem = new QTableWidgetItem( QString::fromStdWString( iterSchema->getTheMonth() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetSchema->setItem( rowIndex, columnIndex++, pItem );

		//车商代码
		pItem = new QTableWidgetItem( QString::fromStdWString( iterSchema->getCarDealerCode() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetSchema->setItem( rowIndex, columnIndex++, pItem );

		//车商名称
		QString carDealerName = QString::fromStdWString( GetCarDealerName( iterSchema->getCarDealerCode() ) );
		pItem                 = new QTableWidgetItem( carDealerName );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetSchema->setItem( rowIndex, columnIndex++, pItem );

		//工时标准
		pItem = new QTableWidgetItem( QString::fromStdWString( iterSchema->getManHourPrice() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetSchema->setItem( rowIndex, columnIndex++, pItem );

		//配件价格
		pItem = new QTableWidgetItem( QString::fromStdWString( iterSchema->getPartPrice() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetSchema->setItem( rowIndex, columnIndex++, pItem );

		//其他理赔支持
		pItem = new QTableWidgetItem( QString::fromStdWString( iterSchema->getClaimSupport() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetSchema->setItem( rowIndex, columnIndex++, pItem );

		//营销活动方案
		pItem = new QTableWidgetItem( QString::fromStdWString( iterSchema->getScheme() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetSchema->setItem( rowIndex, columnIndex++, pItem );

		//是否达成预期
		pItem = new QTableWidgetItem( QString::fromStdWString( iterSchema->getIsQualified() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetSchema->setItem( rowIndex, columnIndex++, pItem );

		columnIndex = 0;
		rowIndex++;
	}

	resizeTableWidgetTab(ui.pTableWidgetSchema, 10);
}
