#include <QFileDialog>
#include <stdexcept>
#include <QMessageBox>
#include <QtWidgets/QtWidgets>

#include "QNewRepairMonitorWidget.h"
#include "../../Data/DataManipulation/Excel/LoadFromExcel.h"
#include "../../Data/DataManipulation/oracle/ImportToOracle.h"
#include "../../util/qt/qt_util.h"

using namespace std;

QNewRepairMonitorWidget::QNewRepairMonitorWidget( QWidget * parent )
	: QWidget( parent )
{
	ui.setupUi( this );

	init();
}

QNewRepairMonitorWidget::~QNewRepairMonitorWidget()
{
}

void QNewRepairMonitorWidget::onImport()
{
	QString caption = "选择要导入的文件";
	QString dir     = ".";
	QString filter  = "Excel文件 (*.xlsx)";

	QStringList files = QFileDialog::getOpenFileNames( nullptr,
	                                                   caption,
	                                                   dir,
	                                                   filter );

	if ( files.count() == 0 )
	{
		return;
	}

	//清理旧数据
	recordVector.clear();

	try
	{
		//遍历，逐个导入
		for ( auto iterFile = files.begin();
		      iterFile != files.end();
		      ++iterFile )
		{
			LoadNewRepairMonitorReportFromXlsx( iterFile->toStdWString(),
			                                    0,
			                                    1,
			                                    recordVector );
		}
	}
	catch ( std::runtime_error & error )
	{
		QMessageBox::critical( nullptr,
		                       "读取失败！",
		                       error.what() );

		return;
	}

	//写入数据库
	try
	{
		//以后要改掉
		string userName = "car_dealer";
		string password = "cpic123456";
		string tnsName  = "xmcx1";

		ImportNewRepairMonitorToOracle( userName, password, tnsName, recordVector );

		//showNewRepairMonitorRecords();
	}
	catch ( runtime_error & error )
	{
		QMessageBox::critical( nullptr,
		                       "保存失败！",
		                       QString::fromUtf8( error.what()) );
		return;
	}

	//提示一下
	QString messageInfo    = "导入%1条记录";
	QString messageCaption = "导入完成";

	QMessageBox::information( nullptr,
	                          messageCaption,
	                          messageInfo.arg( recordVector.size() ) );

	//释放内存
	recordVector.clear();
}

void QNewRepairMonitorWidget::init()
{
	initData();
	initWidgets();
	initSignal();
}

void QNewRepairMonitorWidget::initData()
{
}

void QNewRepairMonitorWidget::initWidgets()
{
	setLayout( ui.pLayoutMain );
}

void QNewRepairMonitorWidget::initSignal()
{
	connect( ui.pButtonImport, SIGNAL( clicked() ), this, SLOT( onImport() ) );
}

void QNewRepairMonitorWidget::showNewRepairMonitorRecords()
{
	ui.pTableWidgeRepairOrder->clearContents();
	ui.pTableWidgeRepairOrder->setRowCount( recordVector.size() );

	int                rowIndex    = 0;
	int                columnIndex = 0;
	QTableWidgetItem * pItem       = nullptr;

	for ( auto iterRecord = recordVector.begin();
	      iterRecord != recordVector.end();
	      ++iterRecord, ++rowIndex )
	{
		columnIndex = 0;

		//
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->分公司名称_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->报案号_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//报案日期
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->报案日期_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//出险日期
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->出险日期_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//出险地点
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->出险地点_ ) );
		pItem->setTextAlignment( Qt::AlignLeft | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//事故车目前位置
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->事故车目前位置_ ) );
		pItem->setTextAlignment( Qt::AlignLeft | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//车损序号
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->车损序号_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//车牌号
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->车牌_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//vin
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->vin码_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//品牌名称
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->品牌名称_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//保单号
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->保单号_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//标的车、三者车
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->标的车_三者车_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//核价金额
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->核价金额_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//结案金额
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->结案金额_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//接报案人分公司
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->接报案人分公司名称_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//接报案人工号 
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->接报案人工号_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//接报案人
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->接报案人名称_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//查勘员
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->查勘员名称_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//第一任务分派时间
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->第一任务分派时间_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//第一车商是否已阅读
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->第一车商是否已阅读_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//第一车商是否预约进厂
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->第一车商是否进厂确认_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//第一车商是否推荐失败
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->第一车商是否推荐失败_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//第一车商是否出厂确认
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterRecord->第一车商是否出场确认_ ) );
		pItem->setTextAlignment( Qt::AlignCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );
	}

	resizeTableWidgetTab( ui.pTableWidgeRepairOrder, 10 );
}
