﻿#include <QFileDialog>
#include <stdexcept>
#include "QRepairOrderWidget.h"
#include <QMessageBox>
#include "../../Data/DataManipulation/Excel/LoadFromExcel.h"
#include "../../Data/DataManipulation/oracle/ImportToOracle.h"
#include "../../util/qt/qt_util.h"

using namespace std;

QRepairOrderWidget::QRepairOrderWidget( QWidget * parent )
	: QWidget( parent )
{
	ui.setupUi( this );

	init();
}

QRepairOrderWidget::~QRepairOrderWidget()
{
}

void QRepairOrderWidget::onImport()
{
	QString fileDir       = ".";
	QString dialogCaption = "打开文件";
	QString filter        = "Excel文件 (*.xlsx)";
	//QStringList fileList;

	try
	{
		//读取文件
		QStringList fileList = QFileDialog::getOpenFileNames( nullptr,
		                                                      dialogCaption,
		                                                      fileDir,
		                                                      filter );

		if ( fileList.count() == 0 )
		{
			return;
		}

		//清理旧数据
		repairOrderVector.clear();

		for ( auto iterFile = fileList.begin();
		      iterFile != fileList.end();
		      ++iterFile )
		{
			LoadRepairOrderFromXlsx( iterFile->toStdWString(),
			                         0,
			                         1,
			                         repairOrderVector );
		}
	}
	catch ( runtime_error & error )
	{
		QMessageBox::critical( nullptr,
		                       "读取失败！",
		                       "数据读取失败!" );

		return;
	}

	//如果没有读取任何记录，就退出！
	if ( repairOrderVector.size() == 0 )
	{
		return;
	}

	//写入数据
	try
	{
		//以后要修改
		string userName = "car_dealer";
		string password = "cpic123456";
		string tnsName  = "xmcx1";

		ImportRepairOrderToOracle( userName,
		                           password,
		                           tnsName,
		                           repairOrderVector );

		showRepairOrder();
	}
	catch ( runtime_error & error )
	{
		QMessageBox::critical( nullptr,
		                       "写入失败",
		                       QString::fromLocal8Bit( error.what() ) );
		return;
	}

	//提示一下
	QString messageInfo = "导入%1条记录";
	QString messageCaption = "导入完成";

	QMessageBox::information(nullptr,
		messageCaption,
		messageInfo.arg(repairOrderVector.size()));
}

void QRepairOrderWidget::init()
{
	initData();
	initWidgets();
	initSignal();
}

void QRepairOrderWidget::initData()
{
}

void QRepairOrderWidget::initWidgets()
{
	setLayout( ui.pLayoutMain );
}

void QRepairOrderWidget::initSignal()
{
	connect( ui.pButtonImport, SIGNAL( clicked() ), this, SLOT( onImport() ) );
}

void QRepairOrderWidget::showRepairOrder()
{
	ui.pTableWidgeRepairOrder->clearContents();
	ui.pTableWidgeRepairOrder->setRowCount( repairOrderVector.size() );

	int                rowIndex    = 0;
	int                columnIndex = 0;
	QTableWidgetItem * pItem       = nullptr;

	for ( auto iterOrder = repairOrderVector.begin();
	      iterOrder != repairOrderVector.end();
	      ++iterOrder, ++rowIndex )
	{
		columnIndex = 0;

		//工单号
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getOrderNo() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//工单类型
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getOrderType() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//报案号
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getNotifyNo() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//出险区域
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getDamageArea() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//出险日期
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getDamageDate() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//创建日期
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getGeneratingDate() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//商业险保单号
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getPolicyNo() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//交强险保单号
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getPolicyNoJqx() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//车牌号
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getPlateNumber() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//品牌名称
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getBrandName() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//是否标的车
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getIsInsuranceObject() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//是否推荐成功
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getIsSuccess() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//推荐车商代码
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getRecommandDealerCode() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//推荐车商名称
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getRecommandDealerName() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//报案推荐车商
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getRecommandDealerNameInNotify() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//查勘推荐车商
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getRecommandDealerNameInSurvey() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//接报案人
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getAgentName() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//查勘员
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getSurveyor() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//工单确认时间
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getCheckDate() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//车辆进厂时间
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getRepairingStartDate() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//车辆出厂时间
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getRepairingFinishDate() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//状态
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getStatus() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//损失项目ID
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getLostItemId() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );

		//查勘员推荐状态
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iterOrder->getSurveyorRecommandStatus() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgeRepairOrder->setItem( rowIndex, columnIndex++, pItem );
	}

	resizeTableWidgetTab( ui.pTableWidgeRepairOrder, 10 );
}
