#include <stdexcept>
#include <QtWidgets/QtWidgets>
#include "QRepairRecommendationWidget.h"
#include "../../Data/DataManipulation/Excel/LoadFromExcel.h"
#include "../../Data/DataManipulation/oracle/ImportToOracle.h"
#include "../../util/qt/qt_util.h"

using namespace std;

QRepairRecommendationWidget::QRepairRecommendationWidget( QWidget * parent )
	: QWidget( parent )
{
	ui.setupUi( this );

	init();
}

QRepairRecommendationWidget::~QRepairRecommendationWidget()
{
}

void QRepairRecommendationWidget::onImport()
{
	//打开文件
	QString     dir      = QString::fromUtf8( "." );
	QString     filter   = QString::fromUtf8( "Excel文件(*.xlsx)" );
	QStringList fileList = QFileDialog::getOpenFileNames( this,
	                                                      QString::fromUtf8( "请选择要导入的数据文件" ),
	                                                      dir,
	                                                      filter );

	//清理旧数据
	recommandationVector.clear();

	//遍历文件列表，导入每一个文件
	try
	{
		for ( auto iterFile = fileList.begin();
		      iterFile != fileList.end();
		      ++iterFile )
		{
			LoadRepairRecommandationFromXlsx( (*iterFile).toStdWString(),
			                                  0,
			                                  1,
			                                  recommandationVector );
		}
	}
	catch ( runtime_error & error )
	{
		//清理数据，退出函数
		recommandationVector.clear();

		QMessageBox::critical( nullptr,
		                       QString::fromUtf8( "读取Excel表格出错！" ),
		                       QString::fromUtf8( error.what() ) );

		return;
	}

	//写入数据
	try
	{
		//以后要修改
		string userName = "car_dealer";
		string password = "cpic123456";
		string tnsName  = "xmcx1";

		ImportRepairRecommandationToOracle( userName, password, tnsName, recommandationVector );
		showRepairRecommandation();
	}
	catch ( runtime_error & error )
	{
		//清理数据，退出函数
		recommandationVector.clear();

		QMessageBox::critical( nullptr,
		                       QString::fromUtf8( "保存数据出错！" ),
		                       QString::fromLocal8Bit( error.what() ) );

		return;
	}

	//提示
	QString messageInfo = QString::fromUtf8( "写入%1了条记录。" ).arg( recommandationVector.size() );

	QMessageBox::information( nullptr,
	                          QString::fromUtf8( "保存成功" ),
	                          messageInfo );
}

void QRepairRecommendationWidget::init()
{
	initData();
	initWidgets();
	initSignal();
}

void QRepairRecommendationWidget::initData()
{
}

void QRepairRecommendationWidget::initWidgets()
{
	setLayout( ui.pLayoutMain );
}

void QRepairRecommendationWidget::initSignal()
{
	connect( ui.pButtonImport, SIGNAL( clicked() ), this, SLOT( onImport() ) );
}

void QRepairRecommendationWidget::showRepairRecommandation()
{
	int                rowIndex    = 0;
	int                columnIndex = 0;
	QTableWidgetItem * pItem       = nullptr;

	ui.pTableWidgetRepairRecommandation->clearContents();
	ui.pTableWidgetRepairRecommandation->setRowCount( recommandationVector.size() );

	for ( auto iter = recommandationVector.begin();
	      iter != recommandationVector.end();
	      ++iter, ++rowIndex )
	{
		columnIndex = 0;

		//工单号
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iter->getOrderNo() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetRepairRecommandation->setItem( rowIndex, columnIndex++, pItem );

		//工单类型
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iter->getOrderType() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetRepairRecommandation->setItem( rowIndex, columnIndex++, pItem );

		//报案号
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iter->getNotifyNo() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetRepairRecommandation->setItem( rowIndex, columnIndex++, pItem );

		//推荐车商代码
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iter->getSuggestedCarDealerCode() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetRepairRecommandation->setItem( rowIndex, columnIndex++, pItem );

		//推荐车商名称
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iter->getSuggestedCarDealerName() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetRepairRecommandation->setItem( rowIndex, columnIndex++, pItem );

		//出险日期
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iter->getDamageDate() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetRepairRecommandation->setItem( rowIndex, columnIndex++, pItem );

		//车牌号
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iter->getPlateNumber() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetRepairRecommandation->setItem( rowIndex, columnIndex++, pItem );

		//品牌名称
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iter->getBrandName() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetRepairRecommandation->setItem( rowIndex, columnIndex++, pItem );

		//短信类型
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iter->getMessageType() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetRepairRecommandation->setItem( rowIndex, columnIndex++, pItem );

		//发送时间
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iter->getMessageSendingDate() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetRepairRecommandation->setItem( rowIndex, columnIndex++, pItem );

		//数据来源
		pItem = new QTableWidgetItem();
		pItem->setText( QString::fromStdWString( iter->getDataSource() ) );
		pItem->setTextAlignment( Qt::AlignHCenter | Qt::AlignVCenter );

		ui.pTableWidgetRepairRecommandation->setItem( rowIndex, columnIndex++, pItem );
	}

	resizeTableWidgetTab( ui.pTableWidgetRepairRecommandation, 10 );
}
